@@ -6,7 +6,7 @@ This is part of BenthicPhotoSurvey. https://bitbucket.org/jkibele/benthic_photo_
 """
 import sys
 from PyQt4.QtGui import QApplication
-from benthic_photo_survey.bps_gui import MainWindow
+from bps_package.bps_gui import MainWindow
 
 if __name__ == '__main__':
     app = QApplication(sys.argv)
